<?php

namespace App\Controllers;

use App\Core\Database;
use App\Services\AuthService;
use App\Services\LanguageService;
use App\Utils\DarkMode;
use App\Services\LogService; // Pour les logs de connexion

/**
 * Contrôleur pour la gestion de l'authentification (connexion, déconnexion).
 */
class AuthController
{
    private $authService;
    private $langService;
    private $logService;

    /**
     * Constructeur du AuthController.
     */
    public function __construct()
    {
        $db = Database::getInstance();
        $this->authService = new AuthService($db);
        $this->langService = new LanguageService(APP_ROOT_DIR . '/src/Lang/');
        $this->logService = new LogService(APP_LOG_PATH);
    }

    /**
     * Affiche le formulaire de connexion.
     * Redirige vers le tableau de bord si l'utilisateur est déjà connecté.
     */
    public function showLoginForm()
    {
        if ($this->authService->isLoggedIn()) {
            header('Location: /dashboard');
            exit();
        }

        // Charge les traductions et la classe pour le mode sombre pour la vue
        global $translations; // Utilise la variable globale chargée dans index.php
        $currentLang = $this->langService->getLanguage();
        $darkModeClass = DarkMode::getBodyClass();

        // Récupère les messages d'erreur/succès de la session
        $error = $_SESSION['error'] ?? null;
        unset($_SESSION['error']); // Supprime le message après l'avoir affiché

        require_once APP_ROOT_DIR . '/src/Views/auth/login.php';
    }

    /**
     * Traite la soumission du formulaire de connexion.
     */
    public function login()
    {
        // Vérifie si la requête est bien un POST
        if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
            header('Location: /login');
            exit();
        }

        $username = trim($_POST['username'] ?? '');
        $password = $_POST['password'] ?? '';
        $ipAddress = $_SERVER['REMOTE_ADDR'];

        // Validation simple des entrées
        if (empty($username) || empty($password)) {
            $_SESSION['error'] = $this->langService->__('login_error_empty_fields');
            header('Location: /login');
            exit();
        }

        if ($this->authService->login($username, $password, $ipAddress)) {
            // Connexion réussie
            header('Location: /dashboard');
            exit();
        } else {
            // Connexion échouée
            $_SESSION['error'] = $this->langService->__('login_error_credentials');
            header('Location: /login');
            exit();
        }
    }

    /**
     * Déconnecte l'utilisateur.
     */
    public function logout()
    {
        $ipAddress = $_SERVER['REMOTE_ADDR'];
        $this->authService->logout($ipAddress);
        header('Location: /login');
        exit();
    }
}
