<?php
// On assume que $translations, $currentLang, $darkModeClass et $error sont définis par le contrôleur
// global $translations; // Déjà global dans index.php si utilisé ici
// global $currentLang;
// global $darkModeClass;
?>
<!DOCTYPE html>
<html lang="<?= htmlspecialchars($currentLang) ?>">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?= htmlspecialchars($translations['login_title']) ?></title>
    <link rel="stylesheet" href="/style.css">
    <link rel="stylesheet" href="/dark-mode.css">
</head>
<body class="<?= htmlspecialchars($darkModeClass) ?>">
    <div class="container">
        <h1><?= htmlspecialchars($translations['login_heading']) ?></h1>

        <?php if (isset($error)): ?>
            <p class="error-message"><?= htmlspecialchars($error); ?></p>
        <?php endif; ?>

        <form action="/login" method="post">
            <label for="username"><?= htmlspecialchars($translations['username']) ?>:</label><br>
            <input type="text" id="username" name="username" required autocomplete="username"><br><br>

            <label for="password"><?= htmlspecialchars($translations['password']) ?>:</label><br>
            <input type="password" id="password" name="password" required autocomplete="current-password"><br><br>

            <button type="submit" class="button primary-button"><?= htmlspecialchars($translations['login_button']) ?></button>
        </form>

        <div class="options">
            <!-- Boutons de changement de langue -->
            <div class="language-switcher">
                <?php foreach (SUPPORTED_LANGUAGES as $lang): ?>
                    <a href="?lang=<?= htmlspecialchars($lang) ?>" class="<?= $currentLang === $lang ? 'active' : '' ?>"><?= htmlspecialchars(strtoupper($lang)) ?></a>
                <?php endforeach; ?>
            </div>

            <!-- Bouton de bascule du mode sombre -->
            <div class="dark-mode-switcher">
                <a href="?dark_mode=<?= \App\Utils\DarkMode::isEnabled() ? 'off' : 'on' ?>" class="button secondary-button">
                    <?= \App\Utils\DarkMode::isEnabled() ? htmlspecialchars($translations['light_mode']) : htmlspecialchars($translations['dark_mode']) ?>
                </a>
            </div>
        </div>
    </div>
</body>
</html>
